Learn R Programming

grt (version 0.2.2)

extractAIC: extractAIC method for class 'glc', 'gqc', 'gcjc', and 'grg'

Description

Extract Akaike's An Information Criteria from a General Linear, Quadratic, or Conjunctive Classifier, or a General Random Guessing model

Usage

# S3 method for glc
extractAIC(fit, scale, k = 2, ...)

# S3 method for gqc extractAIC(fit, scale, k = 2, ...)

# S3 method for gcjc extractAIC(fit, scale, k = 2, ...)

# S3 method for grg extractAIC(fit, scale, k = 2, ...)

Value

A numeric vector of length 2 including:

df

the degrees of freedom for the fitted model fit.

AIC

the Akaike's Information Criterion for fit.

Arguments

fit

object of class glc, gqc, gcjc, or grg

scale

unused argument

k

numeric specifying the penalty per parameter to be used in calculating AIC. Default to 2.

...

further arguments (currently not used).

Details

As with the default method, the criterion used is $$AIC = - 2\log L + k \times \mbox{df},$$ where \(L\) is the likelihood and \(df\) is the degrees of freedom (i.e., the number of free parameters) of fit.

Examples

Run this code
data(subjdemo_2d)
#fit a 2d suboptimal model
fit.2dl <- glc(response ~ x + y, data=subjdemo_2d, 
    category=subjdemo_2d$category, zlimit=7)
extractAIC(fit.2dl)

Run the code above in your browser using DataLab