| glcStruct | R Documentation |
A named list of model parameters that specify a linear decision bound, containing noise, coeffs, and bias.
glcStruct(noise, coeffs, bias)
noise |
a positive non-zero numeric. |
coeffs |
vector. the length of the |
bias |
numeric. |
object of class glcStruct, i.e., a named list containing noise, coeffs, and bias. Returned values are normalized, such that each value are divided by the euclidean norm of the coeffs vector, and the sum of coeffs^2 is 1.
glc,
coef.glcStruct,
logLik.glcStruct,
old2new_par,
new2old_par
params <- glcStruct(noise=10, coeffs=c(1, -1), bias=0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.