| gqcStruct | R Documentation |
A named list of model parameters that specify a quadratic decision bound, containing pnoise, cnoise, coeffs, and bias.
gqcStruct(pnoise, cnoise, coeffs, bias)
pnoise |
a positive non-zero numeric. |
cnoise |
a positive non-zero numeric. |
coeffs |
a vector. The |
bias |
numeric. |
object of class gqcStruct, i.e., a named list containing pnoise, cnoise, coeffs, and bias.
gqc,
logLik.gqcStruct
params <- gqcStruct(pnoise=10, cnoise=100, coeffs=c(1,2,3,4,5), bias=6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.