Learn R Programming

grt (version 0.2.2)

logLik.glcStruct: Log-Likelihood of a 'glcStruct' or 'gcjcStruct' Object

Description

Calculate the log-likelihood of the general linear or conjunctive classifier model applied to a data set.

Usage

# S3 method for glcStruct
logLik(object, response, x, zlimit = Inf, ...)

# S3 method for gcjcStruct logLik(object, response, x, zlimit = Inf, ...)

Value

The log-likelihood for the general linear or conjunctive classifier described by object fitted against the dataset given by response and x.

Arguments

object

object of class glcStruct or gcjcStruct containing the parameter values at which the log-likelihood is to be evaluated.

response

a vector of classification responses used to calculate the log-likelihood of the model.

x

a matrix or dataframe containing values for each stimulus dimensions.

zlimit

integer. Used to truncate the z-scores whose absolute values are greater than zlimit when calculating the log-likelihood. Default to Inf

...

further arguments (currently unused)

See Also

gqc, gqcStruct, logLik.glc, logLik.gcjc

Examples

Run this code
m <- list(c(187, 142), c(213, 98))
covs <- diag(625, ncol=2, nrow=2)
db <- ldb(means=m, covs=covs, noise=10)
data(subjdemo_2d)
logLik(db, subjdemo_2d$response, x=subjdemo_2d[2:3], zlimit=7)

Run the code above in your browser using DataLab