| logLik.gqc | R Documentation |
Extract the log-likelihood of the fitted general quadratic classifier model.
## S3 method for class 'gqc'
logLik(object, ...)
object |
object of class |
... |
further arguments (currently unused) |
The log-likelihood for the general quadratic classifier represented by the estimated parameters in object
This function is intended for indirect internal use by functions such as AIC.
To obtain the log-likelihood of the fitted model applied to new dataset, use logLik.gqcStruct
gqc, logLik.gqcStruct
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.