- x
object of class gqc
- fitdb
logical. If TRUE, the fitted decision bound will be plotted. Default to TRUE
- initdb
logical. If TRUE, the decision bound specified by the initial parameters will be plotted. Default to FALSE
- lims
column matrix of the x, y, and z limits of the plot. If NULL, limits are calculated from the model matrix of x. Default to NULL.
- npoints
number of points per dimension (i.e., x, y, and z) used to plot the decision bound surface. Default is 100.
- alpha
alpha value for the decision bound surface(s) ranging from 0 (fully transparent) to 1 (opaque). Default is .5
- fill
logical. If TRUE, decision bounds (if fitdb or initdb is set to TRUE) should be drawn with filled surfaces. If FALSE, a wire frame should be used. Default to TRUE.
- smooth
logical. If TRUE, smooth shading should be used. Default to FALSE.
- ...
further arguments.