gqc(formula,
data,
category,
par = list(),
zlimit = Inf,
fixed = list(),
opt = c("nlminb", "optim"),
lower=-Inf,
upper=Inf,
control=list())response ~ x1 + x2 + ... where the
response specifies the grouping factor (generally a participant's response) and the right hand side specifies the feature values of the classified stimuli.formula are taken.gqcStruct or named list containing a set of initial parameters used to fit the data.Infpnoise, cnoise, coeffs, and bias parameters should be fixed to the initial value. Default to all FALSE. A fatal error will result ic(.1, .1, rep(-Inf, length(unlist(par))-2)), and c(5000, 5000, rep( Inf, length(unlist(par))-2)), respectively.gqc, i.e., a list containing the following components:terms object used.par is not fully specified in the argument, the function attemps to calculate the initial parameter values by internally calling the functions mcovs and qdb. The response specified in the formula is used as the grouping factor in mcovs.Ashby, F. G. (1992) Multidimensional models of perception and cognition. Lawrence Erlbaum Associates.
glc,
qdb,
logLik.gqc,
logLik.gqcStruct,
plot.gqc,
plot3d.gqcdata(subjdemo_2d)
fit.2dq <- gqc(response ~ x + y, data=subjdemo_2d,
category=subjdemo_2d$category, zlimit=7)Run the code above in your browser using DataLab